@@ -679,11 +679,17 @@ void NV_API_CALL nv_acpi_methods_init(NvU32 *handlesPresent)
         *handlesPresent = *handlesPresent | NV_ACPI_MXMS_HANDLE_PRESENT;
     if (psr_handle)
     {
-        retVal = acpi_bus_get_device(psr_device_handle, &device);
-
-        if (!(ACPI_FAILURE(retVal) || !device))
+        // Since _PSR is not a per-GPU construct we only need to register a
+        // single notifier for the _PSR event. Skip registration for subsequent
+        // devices
+        if (psr_nv_acpi_object == NULL)
         {
-            psr_nv_acpi_object = nv_install_notifier(device, nv_acpi_powersource_hotplug_event);
+            retVal = acpi_bus_get_device(psr_device_handle, &device);
+
+            if (!(ACPI_FAILURE(retVal) || !device))
+            {
+                psr_nv_acpi_object = nv_install_notifier(device, nv_acpi_powersource_hotplug_event);
+            }
         }
     }
 
@@ -744,6 +750,7 @@ void NV_API_CALL nv_acpi_methods_uninit(void)
 
         psr_handle = NULL;
         psr_device_handle = NULL;
+        psr_nv_acpi_object = NULL;
     }
 
     if (nvif_parent_gpu_handle == NULL) 
